pub struct StacktrackReader { /* private fields */ }Implementations
Sourceimpl StacktrackReader
impl StacktrackReader
Sourcepub unsafe fn new(vmo: &Vmo) -> Result<Self, Error>
pub unsafe fn new(vmo: &Vmo) -> Result<Self, Error>
Safety
The caller must guarantee that the vmo is not accessed by others while the returned
instance is alive, usually by taking a snapshot of the VMO that StacktrackWriter
operates on and then reading the snapshot instead.
pub fn iter(&self) -> StacktrackIterator<'_> ⓘ