pub struct StacktrackWriter { /* private fields */ }Expand description
Writer for the Stacktrack VMO.
Implementations
Sourceimpl StacktrackWriter
impl StacktrackWriter
Sourcepub unsafe fn new(vmo: &Vmo) -> Result<Self, Error>
pub unsafe fn new(vmo: &Vmo) -> Result<Self, Error>
Initializes a VMO as an empty table and creates a StacktrackWriter to write into it.
Safety
The caller must guarantee that the vmo is not accessed by others while the returned
instance is alive. However, it always safe to take a snapshot and read that instead.